#
# spec file for package python-sambacc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global bname sambacc

Name:           python-%{bname}
Version:        v0.2+git.108.e7850e0
Release:        2.2
Summary:        Samba Container Configurator
License:        GPL-3.0-or-later
URL:            https://github.com/samba-in-kubernetes/sambacc
Source:         %{bname}-%{version}.tar.bz2
BuildArch:      noarch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
Requires:       python3-pyxattr
Requires:       samba-python3

%python_subpackages

%description
A Python library intended to act as a bridge between a container
environment and Samba servers and utilities. It aims to consolidate, coordinate and
automate all of the low level steps of setting up smbd, users, groups, and other
supporting components.

%package -n %{bname}
Summary:        %{summary}
Requires:       python3-%{bname}

%description -n %{bname}
A set of CLI tools intended to act as a bridge between a container
environment and Samba servers and utilities. It aims to consolidate, coordinate and
automate all of the low level steps of setting up smbd, users, groups, and other
supporting components.

%prep
%autosetup -n %{bname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand rm -r %{buildroot}%{$python_sitelib}/%{bname}-*.dist-info
%python_expand find %{buildroot}%{$python_sitelib} -name *.pyc -delete
sed -i 's;python%{python_version};python3;g' %{buildroot}/%{_bindir}/samba-container
sed -i 's;python%{python_version};python3;g' %{buildroot}/%{_bindir}/samba-dc-container

%files %{python_files}
%{python_sitelib}/%{bname}

%files -n %{bname}
%doc README.*
%{_bindir}/samba-container
%{_bindir}/samba-dc-container
%{_datadir}/%{bname}

%changelog
* Wed Feb 28 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add dependency on setuptools.
* Wed May 10 2023 dmulder@suse.com
- Update to version v0.2+git.108.e7850e0:
  * docs: document the availability of yaml and toml formatted confs
  * extras: have rpm spec recommend extras on fedora 37 & later
  * extras: add our toml and yaml extras to the rpm spec
  * tox: get all test envs that install via pip working with extras
  * setup: add extras for toml and yaml
  * tests: support testing toml with tomli or tomllib
  * sambacc: support tomli for reading toml on older versions
  * tests: add test cases for yaml formatted configuration
  * sambacc: add support for reading YAML formatted configs
  * tests: add test cases for toml formatted configuration
  * sambacc: add support for reading TOML formatted configs
  * copr: add .copr/Makefile for building in COPR system
  * container: default to dnf in build script
  * container: more granular controls of build script behavior
  * container: generate a more robust rpm spec file
  * container: make build script a tad more consistent
  * extras: fix a typo in the rpm spec
  * extras: add additional build deps to the rpm spec file
  * extras: add validation extra as an rpm sub package
  * sambacc: make config module robust to unexpected jsonschema versions
* Tue Apr 18 2023 dmulder@suse.com
- Update to version v0.2+git.88.c81c65a:
  * workflows: add a job to check commit messages
  * gitlint: add a .gitlint configuration file
  * tox: add a gitlint environment
  * tox: add an 'extras' to the python package
  * extras: fix a warning when building on fc37
  * extras: use the new py3-sys tox env in the rpm spec file
  * tox: create a new py3-sys environment
  * workflows: do not run push job if test job fails
  * workflows: add test runs for centos stream9 and fedora 37
  * workflows: use non-shallow git checkout to please setuptools_scm
  * container: inform git that our repo path is acceptable
  * container: always run rpm build as part of a normal build
  * tox: remove jsonschema from the tox deps list
  * sambacc: ignore mypy errors if it can't import jsonschema
  * setup.cfg: add sambacc.schema to package list
  * tox: add schemacheck to verify that generated schema data matches yaml
  * tests: add initial tests of json schema validation
  * commands: extend the context protocol with a require_validation method
  * commands: add cli option & env var to control config validation
  * sambacc: add support for json schema based validation of the config
  * tox: add type definition packages for mypy testing with json schema
  * pyproject: do not require typing in the schema dir
  * schema: commit generated python
  * schema: add a python tool to manage schema files
  * schema: add new json-schema based schema files to the tree
  * tests: supply invalid configuration to GloalConfig directly
  * sambacc: add an initial_data argument to GlobalConfig class
  * sambacc: add a JSONData type for convenience
  * tests: fix a typo in a test name
  * sambacc: rename check_config_data to take it private
  * github: sync mergify rules that handle aged PRs
  * docs: fix incorrect version number in configuration.md
* Thu Apr  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Drop empty %%generate_buildrequires section: no code in the
  section produces build deps.
* Mon Feb  6 2023 dmulder@suse.com
- Update to version v0.2+git.56.9d8b892:
  * container: parameterize the sambacc containerfile
  * container: update build.sh with ability to install dependencies
* Mon Jan 30 2023 dmulder@suse.com
- Update to version v0.2+git.54.f426c23:
  * Revert "container: Switch to CentOS Stream 9 as base image"
  * mergify.yml: Fix a typo
  * container: Switch to CentOS Stream 9 as base image
  * github: add mergify configuration YAML file
  * sambacc: re-format with black version 23.1a1
  * docs: add first full document describing JSON config
  * tox.ini: avoid one tox warning when running py3-mypy
  * pyproject: require type annotations for sambacc function defs
  * sambacc: complete type annotations for container_dns.py
  * sambacc: complete type annotations for simple_waiter.py
* Mon Oct 10 2022 David Mulder <dmulder@suse.com>
- Initial commit of sources
